@@ -24,9 +24,8 @@ class SaSource(api.Source):
   def __init__(self, spec, name='', tablename=None,
                engine=None, connection=None, table=None, metadata=None,
                *args, **kw):
-    super(SaSource, self).__init__(self.ns('sqlalchemy', spec), *args, **kw)
-    self.spec = spec
-    self.name = name
+    super(SaSource, self).__init__(spec, *args, **kw)
+    self.name     = name
     self.engine   = engine or sa.create_engine(spec)
     self.conn     = connection or self.engine.connect()
     self.metadata = metadata or sa.MetaData()
